LogConfig

Struct LogConfig 

pub struct LogConfig {
    pub path: PathBuf,
    pub raw_mode: bool,
    pub offset: Option<u64>,
    pub allow_create: bool,
    pub crypto: Option<CryptoConfig>,
    pub default_chunk_size: u32,
    pub partial_index_write_interval: u64,
    pub full_index_write_interval: u64,
    pub readonly: bool,
}

Fields

path: PathBufraw_mode: booloffset: Option<u64>

Optional file offset where the DB should start.

allow_create: boolcrypto: Option<CryptoConfig>default_chunk_size: u32

Data is chunked into separate slices, which allows incrementally reading large keys. This setting specifies the size of chunks in bytes.

Note that keys can also be created with a custom chunk size.

partial_index_write_interval: u64

Determines after how many journal entries a new partial index snapshot is written.

full_index_write_interval: u64

Determines after how many journal entries a new full index snapshot is written.

readonly: bool